from setuptools import setup
setup(name='wzh123_package',
      version='0.1',
      description='clinical trial information retriver',
      #url='http://github.com/tongling/clinicaltrial',
      author='wangzehan',
      author_email='2287359887@qq.com',
      license='MIT',
      packages=['my_package'],
      zip_safe=False)